## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = TRUE)

## ----eval=FALSE---------------------------------------------------------------
#  if (!require("BiocManager", quietly = TRUE))
#      install.packages("BiocManager")
#  
#  BiocManager::install("funOmics")

## ----eval=FALSE---------------------------------------------------------------
#  if (!require("devtools", quietly = TRUE))
#      install.packages("devtools")
#  
#  devtools::install_github("elisagdelope/funOmics")

## -----------------------------------------------------------------------------
library(funOmics)

## -----------------------------------------------------------------------------
?funOmics::summarize_pathway_level

## -----------------------------------------------------------------------------
# Example usage:
set.seed(1)
g <- 10000
s <- 20
X <- matrix(abs(rnorm(g * s)), nrow = g, dimnames = list(paste0("g", 1:g), paste0("s", 1:s)))
pathways <- as.list(sample(10:100, size = 100, replace = TRUE))
pathways <- lapply(pathways, function(s, g) paste0("g", sample(1:g, size = s, replace = FALSE)), g)
names(pathways) <- paste0("pathway", seq_along(pathways))
print(paste("Dimensions of omics matrix X:", dim(X)[1], "*", dim(X)[2], "; Length of molecular sets list:", length(pathways)))

## -----------------------------------------------------------------------------
print(head(X))

## -----------------------------------------------------------------------------
print(head(pathways))

## -----------------------------------------------------------------------------
min <- 12
pathway_activity <- summarize_pathway_level(X, pathways, type = "mean", minsize = min)
print(paste("Pathway activity score matrix has dimensions:", nrow(pathway_activity), ",", ncol(pathway_activity)))

## -----------------------------------------------------------------------------
print(head(pathway_activity))

## -----------------------------------------------------------------------------
length_sets <- sapply(pathways, function(p) length(p))
short_sets <- names(length_sets[length_sets < min])
print(length_sets[short_sets])

## -----------------------------------------------------------------------------
print(pathways[short_sets])

## -----------------------------------------------------------------------------
pathway_activity <- summarize_pathway_level(X, pathways, type = "pca", minsize = 0)
print(paste("Pathway activity score matrix has dimensions:", nrow(pathway_activity), ",", ncol(pathway_activity)))

## -----------------------------------------------------------------------------
print(head(pathway_activity))

## -----------------------------------------------------------------------------
hsa_kegg_sets_entrez <- get_kegg_sets()
head(hsa_kegg_sets_entrez)

## -----------------------------------------------------------------------------
hsa_kegg_sets_symbol <- get_kegg_sets(geneid_type = "symbol")
hsa_kegg_sets_symbol[1]

## -----------------------------------------------------------------------------
hsa_kegg_sets_ensembl <- get_kegg_sets(geneid_type = "ensembl")
hsa_kegg_sets_ensembl[1]

## -----------------------------------------------------------------------------
ecoli_kegg_sets <- get_kegg_sets(organism = "ecj")
head(ecoli_kegg_sets)

## -----------------------------------------------------------------------------
sI <- sessionInfo()
print(sI, locale = FALSE)

## -----------------------------------------------------------------------------
goccdb <- "https://data.broadinstitute.org/gsea-msigdb/msigdb/release/7.5/c5.go.cc.v7.5.entrez.gmt"
downdb <- sapply(readLines(goccdb), function(x) strsplit(x, "\t")[[1]])
gocc <- sapply(as.matrix(downdb), function(x) x[3:length(x)])
names(gocc) = sapply(as.matrix(downdb), function(x) x[1])
gocc[1:3]

## -----------------------------------------------------------------------------
X_expr <- matrix(abs(rnorm(g * s)), nrow = g, dimnames = list(1:g, paste0("s", 1:s)))
sd_gocc_expr <- summarize_pathway_level(X_expr, gocc, type="mds")
head(sd_gocc_expr)

## -----------------------------------------------------------------------------
library(SummarizedExperiment)
library(airway)
data(airway)
airway

## -----------------------------------------------------------------------------
assayNames(airway)

## -----------------------------------------------------------------------------
head(assay(airway, "counts"))
dim(assay(airway, "counts"))

## -----------------------------------------------------------------------------
kegg_sets <- get_kegg_sets(geneid_type = "ensembl")
head(kegg_sets)

## -----------------------------------------------------------------------------
pathway_activity <- summarize_pathway_level(assay(airway, "counts"), kegg_sets, type = "sd") # note that the NMF operation can take some minutes
print(paste("Pathway activity score matrix has dimensions:", nrow(pathway_activity), ",", ncol(pathway_activity)))

## -----------------------------------------------------------------------------
head(pathway_activity)

## -----------------------------------------------------------------------------
library(MultiAssayExperiment)
assays_list <- list( counts = assay(airway, "counts"), kegg_sd_agg = pathway_activity)
airwayMultiAssay <- MultiAssayExperiment(experiments=assays_list)
colData(airwayMultiAssay) <- colData(airway)
airwayMultiAssay

